# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static music pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, MusicModelPricing

STATIC_MUSIC_PRICING: list[MusicModelPricing] = [
    MusicModelPricing(
        model_id="elevenlabs-eleven-music",
        provider="elevenlabs",
        display_name="ElevenLabs Eleven Music",
        cost_per_minute=0.5,
        max_duration=None,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
        official=True,
        pricing_note=None,
    ),
    MusicModelPricing(
        model_id="soundverse-music",
        provider="soundverse",
        display_name="Soundverse Music Generation",
        cost_per_minute=0.0125,
        max_duration=240,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-01",
        official=True,
        pricing_note="Approximated from ~$0.05/song at ~4 min avg",
    ),
    MusicModelPricing(
        model_id="sunoapi-suno-v4",
        provider="sunoapi",
        display_name="Suno v4 via SunoAPI.org",
        cost_per_minute=0.0075,
        max_duration=240,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-05-01",
        official=False,
        pricing_note="Unofficial. 12 cr/call, 2 songs/call = $0.03/song at 4 min max",
    ),
    MusicModelPricing(
        model_id="sunoapi-suno-v4.5",
        provider="sunoapi",
        display_name="Suno v4.5 via SunoAPI.org",
        cost_per_minute=0.00375,
        max_duration=480,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-01",
        official=False,
        pricing_note="Unofficial. 12 cr/call, 2 songs/call = $0.03/song at 8 min max",
    ),
    MusicModelPricing(
        model_id="sunoapi-suno-v4.5-all",
        provider="sunoapi",
        display_name="Suno v4.5 All via SunoAPI.org",
        cost_per_minute=0.00375,
        max_duration=480,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-01",
        official=False,
        pricing_note="Unofficial. 12 cr/call, 2 songs/call = $0.03/song at 8 min max",
    ),
    MusicModelPricing(
        model_id="sunoapi-suno-v4.5-plus",
        provider="sunoapi",
        display_name="Suno v4.5 Plus via SunoAPI.org",
        cost_per_minute=0.00375,
        max_duration=480,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-01",
        official=False,
        pricing_note="Unofficial. 12 cr/call, 2 songs/call = $0.03/song at 8 min max",
    ),
    MusicModelPricing(
        model_id="sunoapi-suno-v5",
        provider="sunoapi",
        display_name="Suno v5 via SunoAPI.org",
        cost_per_minute=0.00375,
        max_duration=480,
        output_format="mp3",
        vocals=True,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-01",
        official=False,
        pricing_note="Unofficial. 12 cr/call, 2 songs/call = $0.03/song at 8 min max",
    ),
]
