# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static image pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, ImageModelPricing

STATIC_IMAGE_PRICING: list[ImageModelPricing] = [
    ImageModelPricing(
        model_id="dall-e-2-1024",
        provider="openai",
        display_name="DALL-E 2 Standard 1024x1024",
        price_per_image=0.02,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2022-11-01",
    ),
    ImageModelPricing(
        model_id="dall-e-3-hd-1024",
        provider="openai",
        display_name="DALL-E 3 HD 1024x1024",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution="1792x1024",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-10-01",
    ),
    ImageModelPricing(
        model_id="dall-e-3-hd-1792",
        provider="openai",
        display_name="DALL-E 3 HD 1792x1024",
        price_per_image=0.12,
        price_per_megapixel=None,
        default_resolution="1792x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-10-01",
    ),
    ImageModelPricing(
        model_id="dall-e-3-standard-1024",
        provider="openai",
        display_name="DALL-E 3 Standard 1024x1024",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution="1792x1024",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-10-01",
    ),
    ImageModelPricing(
        model_id="dall-e-3-standard-1792",
        provider="openai",
        display_name="DALL-E 3 Standard 1792x1024",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1792x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2023-10-01",
    ),
    ImageModelPricing(
        model_id="fal-flux-1-dev",
        provider="fal",
        display_name="fal FLUX.1 Dev",
        price_per_image=0.025,
        price_per_megapixel=0.025,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-08-01",
    ),
    ImageModelPricing(
        model_id="fal-flux-1-kontext-pro",
        provider="fal",
        display_name="Flux Kontext Pro",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-29",
    ),
    ImageModelPricing(
        model_id="fal-flux-1-schnell",
        provider="fal",
        display_name="fal FLUX.1 Schnell",
        price_per_image=0.003,
        price_per_megapixel=0.003,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-08-01",
    ),
    ImageModelPricing(
        model_id="fal-flux-2-flex",
        provider="fal",
        display_name="FLUX.2 [flex]",
        price_per_image=0.05,
        price_per_megapixel=0.05,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["jpeg", "png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-25",
    ),
    ImageModelPricing(
        model_id="fal-flux-2-pro",
        provider="fal",
        display_name="FLUX.2 [pro] Text-to-Image",
        price_per_image=0.03,
        price_per_megapixel=0.03,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["jpeg", "png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-ideogram-v2",
        provider="fal",
        display_name="Ideogram V2",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-ideogram-v3",
        provider="fal",
        display_name="fal Ideogram V3",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
    ),
    ImageModelPricing(
        model_id="fal-nano-banana-2",
        provider="fal",
        display_name="Nano Banana 2",
        price_per_image=0.0398,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
    ),
    ImageModelPricing(
        model_id="fal-nano-banana-pro",
        provider="fal",
        display_name="fal Nano Banana Pro",
        price_per_image=0.15,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
    ),
    ImageModelPricing(
        model_id="fal-qwen-image-2-pro",
        provider="fal",
        display_name="Qwen Image",
        price_per_image=0.02,
        price_per_megapixel=0.02,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-01",
    ),
    ImageModelPricing(
        model_id="fal-recraft-v3",
        provider="fal",
        display_name="Recraft V3",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["webp", "jpeg", "png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-recraft-v4-pro",
        provider="fal",
        display_name="fal Recraft V4 Pro",
        price_per_image=0.25,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="fal-sd3",
        provider="fal",
        display_name="Stable Diffusion 3 Medium",
        price_per_image=0.035,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="flux-1-fill-pro",
        provider="bfl",
        display_name="FLUX.1 Fill [pro]",
        price_per_image=0.05,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-11-01",
    ),
    ImageModelPricing(
        model_id="flux-1-kontext-max",
        provider="bfl",
        display_name="FLUX.1 Kontext [max]",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-29",
    ),
    ImageModelPricing(
        model_id="flux-1-kontext-pro",
        provider="bfl",
        display_name="FLUX.1 Kontext [pro]",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-29",
    ),
    ImageModelPricing(
        model_id="flux-1.1-pro",
        provider="bfl",
        display_name="FLUX1.1 [pro]",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-10-01",
    ),
    ImageModelPricing(
        model_id="flux-1.1-pro-raw",
        provider="bfl",
        display_name="FLUX1.1 [pro] Raw",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-11-01",
    ),
    ImageModelPricing(
        model_id="flux-1.1-pro-ultra",
        provider="bfl",
        display_name="FLUX1.1 [pro] Ultra",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="ultra",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-11-01",
    ),
    ImageModelPricing(
        model_id="flux-2-flex",
        provider="bfl",
        display_name="FLUX.2 [flex]",
        price_per_image=0.05,
        price_per_megapixel=0.05,
        default_resolution="1024x1024",
        quality_tier="ultra",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-25",
    ),
    ImageModelPricing(
        model_id="flux-2-klein-4b",
        provider="bfl",
        display_name="FLUX.2 [klein] 4B",
        price_per_image=0.014,
        price_per_megapixel=0.014,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-15",
    ),
    ImageModelPricing(
        model_id="flux-2-klein-9b",
        provider="bfl",
        display_name="FLUX.2 [klein] 9B",
        price_per_image=0.015,
        price_per_megapixel=0.015,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-01-15",
    ),
    ImageModelPricing(
        model_id="flux-2-pro",
        provider="bfl",
        display_name="FLUX.2 [pro]",
        price_per_image=0.03,
        price_per_megapixel=0.03,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-25",
    ),
    ImageModelPricing(
        model_id="gpt-image-1-high",
        provider="openai",
        display_name="GPT Image 1 High",
        price_per_image=0.167,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="ultra",
        max_resolution="1024x1536",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-23",
    ),
    ImageModelPricing(
        model_id="gpt-image-1-low",
        provider="openai",
        display_name="GPT Image 1 Low",
        price_per_image=0.011,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution="1024x1536",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-23",
    ),
    ImageModelPricing(
        model_id="gpt-image-1-medium",
        provider="openai",
        display_name="GPT Image 1 Medium",
        price_per_image=0.042,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution="1024x1536",
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-23",
    ),
    ImageModelPricing(
        model_id="grok-imagine-image",
        provider="xai",
        display_name="Grok Imagine Image",
        price_per_image=0.02,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="grok-imagine-image-pro",
        provider="xai",
        display_name="Grok Imagine Image Pro",
        price_per_image=0.07,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="ideogram-v3",
        provider="ideogram",
        display_name="Ideogram 3.0 Default",
        price_per_image=0.016,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="ideogram-v3-turbo",
        provider="ideogram",
        display_name="Ideogram 3.0 Turbo",
        price_per_image=0.008,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="imagen-3",
        provider="google",
        display_name="Imagen 3",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-08-01",
    ),
    ImageModelPricing(
        model_id="imagen-4-fast",
        provider="google",
        display_name="Imagen 4 Fast",
        price_per_image=0.02,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
    ),
    ImageModelPricing(
        model_id="imagen-4-standard",
        provider="google",
        display_name="Imagen 4 Standard",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
    ),
    ImageModelPricing(
        model_id="imagen-4-ultra",
        provider="google",
        display_name="Imagen 4 Ultra",
        price_per_image=0.06,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="ultra",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-05-01",
    ),
    ImageModelPricing(
        model_id="recraft-v4-raster",
        provider="recraft",
        display_name="Recraft V4 (Raster)",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg", "webp"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="recraft-v4-vector",
        provider="recraft",
        display_name="Recraft V4 Vector",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["svg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="sd-3.5-large",
        provider="stability",
        display_name="Stable Diffusion 3.5 Large",
        price_per_image=0.065,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="hd",
        max_resolution=None,
        supported_formats=["png", "jpeg", "webp"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-10-22",
    ),
    ImageModelPricing(
        model_id="sd-3.5-large-turbo",
        provider="stability",
        display_name="Stable Diffusion 3.5 Large Turbo",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg", "webp"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-10-22",
    ),
    ImageModelPricing(
        model_id="seedream-4.5",
        provider="bytedance",
        display_name="Seedream 4.5",
        price_per_image=0.04,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-15",
    ),
    ImageModelPricing(
        model_id="stable-image-core",
        provider="stability",
        display_name="Stable Image Core",
        price_per_image=0.03,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="standard",
        max_resolution=None,
        supported_formats=["png", "jpeg", "webp"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-04-01",
    ),
    ImageModelPricing(
        model_id="stable-image-ultra",
        provider="stability",
        display_name="Stable Image Ultra",
        price_per_image=0.08,
        price_per_megapixel=None,
        default_resolution="1024x1024",
        quality_tier="ultra",
        max_resolution=None,
        supported_formats=["png", "jpeg", "webp"],
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-04-01",
    ),
]
