# DO NOT EDIT — generated from registry/*.yaml by `npm run generate-static`
"""Static text model pricing data for the PriceToken SDK."""

from __future__ import annotations

from .types import FreshnessInfo, ModelPricing

STATIC_PRICING: list[ModelPricing] = [
    ModelPricing(
        model_id="claude-haiku-4-5-20251001",
        provider="anthropic",
        display_name="Claude Haiku 4.5",
        input_per_m_tok=1,
        output_per_m_tok=5,
        context_window=200_000,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-10-01",
    ),
    ModelPricing(
        model_id="claude-opus-4-6",
        provider="anthropic",
        display_name="Claude Opus 4.6",
        input_per_m_tok=5,
        output_per_m_tok=25,
        context_window=200_000,
        max_output_tokens=131_072,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-05",
    ),
    ModelPricing(
        model_id="claude-sonnet-4-6",
        provider="anthropic",
        display_name="Claude Sonnet 4.6",
        input_per_m_tok=3,
        output_per_m_tok=15,
        context_window=200_000,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-17",
    ),
    ModelPricing(
        model_id="command-r",
        provider="cohere",
        display_name="Command R 03-2024",
        input_per_m_tok=0.5,
        output_per_m_tok=1.5,
        context_window=128_000,
        max_output_tokens=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-03-01",
    ),
    ModelPricing(
        model_id="command-r-plus",
        provider="cohere",
        display_name="Command R+ 08-2024",
        input_per_m_tok=2.5,
        output_per_m_tok=10,
        context_window=128_000,
        max_output_tokens=None,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-08-01",
    ),
    ModelPricing(
        model_id="deepseek-chat",
        provider="deepseek",
        display_name="DeepSeek Chat (V3.2)",
        input_per_m_tok=0.28,
        output_per_m_tok=0.42,
        context_window=131_072,
        max_output_tokens=8192,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
    ),
    ModelPricing(
        model_id="deepseek-reasoner",
        provider="deepseek",
        display_name="DeepSeek Reasoner (V3.2)",
        input_per_m_tok=0.28,
        output_per_m_tok=0.42,
        context_window=131_072,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-01",
    ),
    ModelPricing(
        model_id="gemini-2.0-flash",
        provider="google",
        display_name="Gemini 2.0 Flash",
        input_per_m_tok=0.1,
        output_per_m_tok=0.4,
        context_window=1_000_000,
        max_output_tokens=8192,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-05",
    ),
    ModelPricing(
        model_id="gemini-2.0-flash-lite",
        provider="google",
        display_name="Gemini 2.0 Flash-Lite",
        input_per_m_tok=0.075,
        output_per_m_tok=0.3,
        context_window=1_048_576,
        max_output_tokens=8192,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-02-25",
    ),
    ModelPricing(
        model_id="gemini-2.5-flash",
        provider="google",
        display_name="Gemini 2.5 Flash",
        input_per_m_tok=0.3,
        output_per_m_tok=2.5,
        context_window=1_000_000,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-17",
    ),
    ModelPricing(
        model_id="gemini-2.5-flash-lite",
        provider="google",
        display_name="Gemini 2.5 Flash-Lite",
        input_per_m_tok=0.1,
        output_per_m_tok=0.4,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-07-22",
    ),
    ModelPricing(
        model_id="gemini-2.5-pro",
        provider="google",
        display_name="Gemini 2.5 Pro",
        input_per_m_tok=1.25,
        output_per_m_tok=10,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-17",
    ),
    ModelPricing(
        model_id="gemini-3-flash-preview",
        provider="google",
        display_name="Gemini 3 Flash Preview",
        input_per_m_tok=0.5,
        output_per_m_tok=3,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-17",
    ),
    ModelPricing(
        model_id="gemini-3-pro-preview",
        provider="google",
        display_name="Gemini 3 Pro Preview",
        input_per_m_tok=2,
        output_per_m_tok=12,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="deprecated",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-20",
    ),
    ModelPricing(
        model_id="gemini-3.1-flash-lite-preview",
        provider="google",
        display_name="Gemini 3.1 Flash-Lite Preview",
        input_per_m_tok=0.25,
        output_per_m_tok=1.5,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-03",
    ),
    ModelPricing(
        model_id="gemini-3.1-pro-preview",
        provider="google",
        display_name="Gemini 3.1 Pro Preview",
        input_per_m_tok=2,
        output_per_m_tok=12,
        context_window=1_048_576,
        max_output_tokens=65536,
        source="seed",
        status="preview",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-19",
    ),
    ModelPricing(
        model_id="gpt-4.1",
        provider="openai",
        display_name="GPT-4.1",
        input_per_m_tok=2,
        output_per_m_tok=8,
        context_window=1_000_000,
        max_output_tokens=32768,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-14",
    ),
    ModelPricing(
        model_id="gpt-4.1-mini",
        provider="openai",
        display_name="GPT-4.1 Mini",
        input_per_m_tok=0.4,
        output_per_m_tok=1.6,
        context_window=1_000_000,
        max_output_tokens=32768,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-14",
    ),
    ModelPricing(
        model_id="gpt-4.1-nano",
        provider="openai",
        display_name="GPT-4.1 Nano",
        input_per_m_tok=0.1,
        output_per_m_tok=0.4,
        context_window=1_000_000,
        max_output_tokens=32768,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-14",
    ),
    ModelPricing(
        model_id="gpt-4o",
        provider="openai",
        display_name="GPT-4o",
        input_per_m_tok=2.5,
        output_per_m_tok=10,
        context_window=128_000,
        max_output_tokens=16384,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-05-13",
    ),
    ModelPricing(
        model_id="gpt-4o-mini",
        provider="openai",
        display_name="GPT-4o Mini",
        input_per_m_tok=0.15,
        output_per_m_tok=0.6,
        context_window=128_000,
        max_output_tokens=16384,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2024-07-18",
    ),
    ModelPricing(
        model_id="gpt-5",
        provider="openai",
        display_name="GPT-5",
        input_per_m_tok=1.25,
        output_per_m_tok=10,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-08-07",
    ),
    ModelPricing(
        model_id="gpt-5-mini",
        provider="openai",
        display_name="GPT-5 Mini",
        input_per_m_tok=0.25,
        output_per_m_tok=2,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-08-07",
    ),
    ModelPricing(
        model_id="gpt-5-nano",
        provider="openai",
        display_name="GPT-5 Nano",
        input_per_m_tok=0.05,
        output_per_m_tok=0.4,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-08-07",
    ),
    ModelPricing(
        model_id="gpt-5.1",
        provider="openai",
        display_name="GPT-5.1",
        input_per_m_tok=1.25,
        output_per_m_tok=10,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-13",
    ),
    ModelPricing(
        model_id="gpt-5.2",
        provider="openai",
        display_name="GPT-5.2",
        input_per_m_tok=1.75,
        output_per_m_tok=14,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-12-11",
    ),
    ModelPricing(
        model_id="gpt-5.3-chat-latest",
        provider="openai",
        display_name="GPT-5.3 Chat Latest",
        input_per_m_tok=1.75,
        output_per_m_tok=14,
        context_window=128_000,
        max_output_tokens=16384,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-03",
    ),
    ModelPricing(
        model_id="gpt-5.3-codex",
        provider="openai",
        display_name="GPT-5.3 Codex",
        input_per_m_tok=1.75,
        output_per_m_tok=14,
        context_window=400_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-02-24",
    ),
    ModelPricing(
        model_id="gpt-5.4",
        provider="openai",
        display_name="GPT-5.4",
        input_per_m_tok=2.5,
        output_per_m_tok=15,
        context_window=1_050_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
    ),
    ModelPricing(
        model_id="gpt-5.4-pro",
        provider="openai",
        display_name="GPT-5.4 Pro",
        input_per_m_tok=30,
        output_per_m_tok=180,
        context_window=1_050_000,
        max_output_tokens=128_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2026-03-05",
    ),
    ModelPricing(
        model_id="grok-3",
        provider="xai",
        display_name="Grok 3",
        input_per_m_tok=3,
        output_per_m_tok=15,
        context_window=131_072,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-09",
    ),
    ModelPricing(
        model_id="grok-3-mini",
        provider="xai",
        display_name="Grok 3 Mini",
        input_per_m_tok=0.3,
        output_per_m_tok=0.5,
        context_window=131_072,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-09",
    ),
    ModelPricing(
        model_id="grok-4",
        provider="xai",
        display_name="Grok 4",
        input_per_m_tok=3,
        output_per_m_tok=15,
        context_window=256_000,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-07-09",
    ),
    ModelPricing(
        model_id="grok-4.1-fast",
        provider="xai",
        display_name="Grok 4.1 Fast",
        input_per_m_tok=0.2,
        output_per_m_tok=0.5,
        context_window=2_000_000,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-11-19",
    ),
    ModelPricing(
        model_id="jamba-1.5-mini",
        provider="ai21",
        display_name="Jamba Mini",
        input_per_m_tok=0.2,
        output_per_m_tok=0.4,
        context_window=256_000,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-01",
    ),
    ModelPricing(
        model_id="jamba-large-1.7",
        provider="ai21",
        display_name="Jamba Large",
        input_per_m_tok=2,
        output_per_m_tok=8,
        context_window=256_000,
        max_output_tokens=None,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-08-01",
    ),
    ModelPricing(
        model_id="o3",
        provider="openai",
        display_name="o3",
        input_per_m_tok=2,
        output_per_m_tok=8,
        context_window=200_000,
        max_output_tokens=100_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-16",
    ),
    ModelPricing(
        model_id="o3-mini",
        provider="openai",
        display_name="o3 Mini",
        input_per_m_tok=1.1,
        output_per_m_tok=4.4,
        context_window=200_000,
        max_output_tokens=100_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-01-31",
    ),
    ModelPricing(
        model_id="o3-pro",
        provider="openai",
        display_name="o3 Pro",
        input_per_m_tok=20,
        output_per_m_tok=80,
        context_window=200_000,
        max_output_tokens=100_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-06-10",
    ),
    ModelPricing(
        model_id="o4-mini",
        provider="openai",
        display_name="o4 Mini",
        input_per_m_tok=1.1,
        output_per_m_tok=4.4,
        context_window=200_000,
        max_output_tokens=100_000,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-04-16",
    ),
    ModelPricing(
        model_id="qwen3-max",
        provider="qwen",
        display_name="Qwen3 Max",
        input_per_m_tok=0.3472,
        output_per_m_tok=1.3889,
        context_window=262_144,
        max_output_tokens=65536,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-09-23",
    ),
    ModelPricing(
        model_id="qwq-32b",
        provider="qwen",
        display_name="QwQ Plus",
        input_per_m_tok=0.2222,
        output_per_m_tok=0.5556,
        context_window=131_072,
        max_output_tokens=8192,
        source="seed",
        status="active",
        confidence="high",
        confidence_score=99,
        confidence_level="high",
        freshness=FreshnessInfo(last_verified="", age_hours=0, stale=False),
        last_updated=None,
        launch_date="2025-03-05",
    ),
]
